@@ -463,27 +463,29 @@ class opensshStatus(StatusMenuItem):
         self.sshConnected = int(getoutput("netstat -t | grep -c :ssh[[:space:]]*[0-9].*ESTABLISHED"))
         
     def sshAllUsers(self):
-        sshNetstat = " ".join(getoutput("netstat -t | grep :ssh.*ESTABLISHED").split()).split()
+        sshNetstat = getoutput("netstat -t | grep :ssh.*ESTABLISHED").split("\n")
         
         countAllWLAN = 0
-        for element in sshNetstat:
-            if self.wlanIP in element:
+        for line in sshNetstat:
+            if self.wlanIP in line:
                 countAllWLAN += 1
-        countInWLAN = 0
-        for element in sshNetstat:
-            if self.wlanIP + ":ssh" in element:
-                countInWLAN += 1
-        countOutWLAN = countAllWLAN - countInWLAN
+        countOutWLAN = 0
+        for line in sshNetstat:
+            line = " ".join(line.split())
+            if self.wlanIP + ":ssh ESTABLISHED" in line:
+                countOutWLAN += 1
+        countInWLAN = countAllWLAN - countOutWLAN
         
         countAllUSB = 0
-        for element in sshNetstat:
-            if self.usbIP in element:
+        for line in sshNetstat:
+            if self.usbIP in line:
                 countAllUSB += 1
-        countInUSB = 0
-        for element in sshNetstat:
-            if self.usbIP + ":ssh" in element:
-                countInUSB += 1
-        countOutUSB = countAllUSB - countInUSB
+        countOutUSB = 0
+        for line in sshNetstat:
+            line = " ".join(line.split())
+            if self.usbIP + ":ssh ESTABLISHED" in line:
+                countOutUSB += 1
+        countInUSB = countAllUSB - countOutUSB
         
         self.sshConnected = countInWLAN + countInUSB
         
@@ -1004,29 +1006,31 @@ class opensshStatus(StatusMenuItem):
         self.showAllDialog = False
             
     def sshCountAll(self, dummy):
-        sshNetstat = " ".join(getoutput("netstat -t | grep :ssh.*ESTABLISHED").split()).split()
+        sshNetstat = getoutput("netstat -t | grep :ssh.*ESTABLISHED").split("\n")
         
         countAllWLAN = 0
-        for element in sshNetstat:
-            if self.wlanIP in element:
+        for line in sshNetstat:
+            if self.wlanIP in line:
                 countAllWLAN += 1
-        countInWLAN = 0
-        for element in sshNetstat:
-            if self.wlanIP + ":ssh" in element:
-                countInWLAN += 1
-        countOutWLAN = countAllWLAN - countInWLAN
+        countOutWLAN = 0
+        for line in sshNetstat:
+            line = " ".join(line.split())
+            if self.wlanIP + ":ssh ESTABLISHED" in line:
+                countOutWLAN += 1
+        countInWLAN = countAllWLAN - countOutWLAN
         self.labelCountInWLAN = countInWLAN
         self.labelCountOutWLAN = countOutWLAN
         
         countAllUSB = 0
-        for element in sshNetstat:
-            if self.usbIP in element:
+        for line in sshNetstat:
+            if self.usbIP in line:
                 countAllUSB += 1
-        countInUSB = 0
-        for element in sshNetstat:
-            if self.usbIP + ":ssh" in element:
-                countInUSB += 1
-        countOutUSB = countAllUSB - countInUSB
+        countOutUSB = 0
+        for line in sshNetstat:
+            line = " ".join(line.split())
+            if self.usbIP + ":ssh ESTABLISHED" in line:
+                countOutUSB += 1
+        countInUSB = countAllUSB - countOutUSB
         self.labelCountInUSB = countInUSB
         self.labelCountOutUSB = countOutUSB
         
